==> heptapod-rails-0.22.0.tar.gz: heptapod-rails-0.22.0/spec/frontend/serverless/store/actions_spec.js <==
import MockAdapter from 'axios-mock-adapter';
import testAction from 'helpers/vuex_action_helper';
import axios from '~/lib/utils/axios_utils';
import statusCodes from '~/lib/utils/http_status';
import { fetchFunctions, fetchMetrics } from '~/serverless/store/actions';
import { mockServerlessFunctions, mockMetrics } from '../mock_data';
import { adjustMetricQuery } from '../utils';

describe('ServerlessActions', () => {
  describe('fetchFunctions', () => {
    it('should successfully fetch functions', (done) => {
      const endpoint = '/functions';
      const mock = new MockAdapter(axios);
      mock.onGet(endpoint).reply(statusCodes.OK, JSON.stringify(mockServerlessFunctions));

      testAction(
        fetchFunctions,
        { functionsPath: endpoint },
        {},
        [],
        [
          { type: 'requestFunctionsLoading' },
          { type: 'receiveFunctionsSuccess', payload: mockServerlessFunctions },
        ],
        () => {
          mock.restore();
          done();
        },
      );
    });

    it('should successfully retry', (done) => {
      const endpoint = '/functions';
      const mock = new MockAdapter(axios);
      mock
        .onGet(endpoint)
        .reply(() => new Promise((resolve) => setTimeout(() => resolve(200), Infinity)));

      testAction(
        fetchFunctions,
        { functionsPath: endpoint },
        {},
        [],
        [{ type: 'requestFunctionsLoading' }],
        () => {
          mock.restore();
          done();
        },
      );
    });
  });

  describe('fetchMetrics', () => {
    it('should return no prometheus', (done) => {
      const endpoint = '/metrics';
      const mock = new MockAdapter(axios);
      mock.onGet(endpoint).reply(statusCodes.NO_CONTENT);

      testAction(
        fetchMetrics,
        { metricsPath: endpoint, hasPrometheus: false },
        {},
        [],
        [{ type: 'receiveMetricsNoPrometheus' }],
        () => {
          mock.restore();
          done();
        },
      );
    });

    it('should successfully fetch metrics', (done) => {
      const endpoint = '/metrics';
      const mock = new MockAdapter(axios);
      mock.onGet(endpoint).reply(statusCodes.OK, JSON.stringify(mockMetrics));

      testAction(
        fetchMetrics,
        { metricsPath: endpoint, hasPrometheus: true },
        {},
        [],
        [{ type: 'receiveMetricsSuccess', payload: adjustMetricQuery(mockMetrics) }],
        () => {
          mock.restore();
          done();
        },
      );
    });
  });
});

==> heptapod-rails-0.32.1.tar.gz: heptapod-rails-0.32.1/spec/frontend/serverless/store/actions_spec.js <==
import MockAdapter from 'axios-mock-adapter';
import testAction from 'helpers/vuex_action_helper';
import axios from '~/lib/utils/axios_utils';
import statusCodes from '~/lib/utils/http_status';
import { fetchFunctions, fetchMetrics } from '~/serverless/store/actions';
import { mockServerlessFunctions, mockMetrics } from '../mock_data';
import { adjustMetricQuery } from '../utils';

describe('ServerlessActions', () => {
  let mock;

  beforeEach(() => {
    mock = new MockAdapter(axios);
  });

  afterEach(() => {
    mock.restore();
  });

  describe('fetchFunctions', () => {
    it('should successfully fetch functions', () => {
      const endpoint = '/functions';
      mock.onGet(endpoint).reply(statusCodes.OK, JSON.stringify(mockServerlessFunctions));

      return testAction(
        fetchFunctions,
        { functionsPath: endpoint },
        {},
        [],
        [
          { type: 'requestFunctionsLoading' },
          { type: 'receiveFunctionsSuccess', payload: mockServerlessFunctions },
        ],
      );
    });

    it('should successfully retry', () => {
      const endpoint = '/functions';
      mock
        .onGet(endpoint)
        .reply(() => new Promise((resolve) => setTimeout(() => resolve(200), Infinity)));

      return testAction(
        fetchFunctions,
        { functionsPath: endpoint },
        {},
        [],
        [{ type: 'requestFunctionsLoading' }],
      );
    });
  });

  describe('fetchMetrics', () => {
    it('should return no prometheus', () => {
      const endpoint = '/metrics';
      mock.onGet(endpoint).reply(statusCodes.NO_CONTENT);

      return testAction(
        fetchMetrics,
        { metricsPath: endpoint, hasPrometheus: false },
        {},
        [],
        [{ type: 'receiveMetricsNoPrometheus' }],
      );
    });

    it('should successfully fetch metrics', () => {
      const endpoint = '/metrics';
      mock.onGet(endpoint).reply(statusCodes.OK, JSON.stringify(mockMetrics));

      return testAction(
        fetchMetrics,
        { metricsPath: endpoint, hasPrometheus: true },
        {},
        [],
        [{ type: 'receiveMetricsSuccess', payload: adjustMetricQuery(mockMetrics) }],
      );
    });
  });
});
